pub fn Icon(props: IconProps) -> impl IntoViewExpand description
The Icon component.
Required Props
- icon:
impl Into<Signal<icondata_core::Icon>>- The icon to render.
Optional Props
- width:
impl Into<MaybeProp<String>>- The width of the icon (horizontal side length of the square surrounding the icon). Defaults to “1em”.
- height:
impl Into<MaybeProp<String>>- The height of the icon (vertical side length of the square surrounding the icon). Defaults to “1em”.
- class:
impl Into<MaybeProp<String>>- HTML class attribute.
- style:
impl Into<Signal<String>>- HTML style attribute.
- on_click:
impl Into<ArcOneCallback<ev::MouseEvent>>- Callback when clicking on the icon.